==> transmission-2.04.tar.bz2: transmission-2.04/gtk/tr-window.h <==
/******************************************************************************
 * $Id: tr-window.h 6997 2008-10-31 04:16:44Z charles $
 *
 * Copyright (c) 2006-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TR_WINDOW_H
#define TR_WINDOW_H

#include <gtk/gtk.h>
#include "tr-core.h"

typedef GtkWindow TrWindow;

GtkTreeSelection * tr_window_get_selection( TrWindow* wind );

GtkWidget        * tr_window_new( GtkUIManager * uim, TrCore * core );

void               tr_window_update( TrWindow * wind );

#endif

==> transmission_2.13.orig.tar.bz2: transmission-2.13/gtk/tr-window.h <==
/******************************************************************************
 * $Id: tr-window.h 10937 2010-07-04 06:07:21Z charles $
 *
 * Copyright (c) 2006-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TR_WINDOW_H
#define TR_WINDOW_H

#include <gtk/gtk.h>
#include <libtransmission/utils.h> /* tr_formatter_speed_KBps() */
#include "tr-core.h"

typedef GtkWindow TrWindow;

GtkTreeSelection * tr_window_get_selection( TrWindow * );

GtkWidget        * tr_window_new( GtkUIManager * uim, TrCore * core );

void               tr_window_update( TrWindow * );

void               tr_window_set_busy( TrWindow *, gboolean isBusy );

#endif
